==> jgit_3.7.1.orig.tar.xz: jgit-3.7.1.201504261725-r/org.eclipse.jgit.archive/src/org/eclipse/jgit/archive/ArchiveFormats.java <==
/*
 * Copyright (C) 2013 Google Inc.
 * and other copyright owners as documented in the project's IP log.
 *
 * This program and the accompanying materials are made available
 * under the terms of the Eclipse Distribution License v1.0 which
 * accompanies this distribution, is reproduced below, and is
 * available at http://www.eclipse.org/org/documents/edl-v10.php
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided
 *   with the distribution.
 *
 * - Neither the name of the Eclipse Foundation, Inc. nor the
 *   names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior
 *   written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.eclipse.jgit.archive;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.jgit.api.ArchiveCommand;

/**
 * Registers all format types from the org.eclipse.jgit.archive
 * package for use via the ArchiveCommand API.
 *
 * See {@link FormatActivator} for an OSGi bundle activator
 * that performs the same registration automatically.
 */
public class ArchiveFormats {
	private static final List<String> myFormats = new ArrayList<String>();

	private static final void register(String name, ArchiveCommand.Format<?> fmt) {
		myFormats.add(name);
		ArchiveCommand.registerFormat(name, fmt);
	}

	/**
	 * Register all included archive formats so they can be used
	 * as arguments to the ArchiveCommand.setFormat() method.
	 *
	 * Not thread-safe.
	 */
	public static void registerAll() {
		register("tar", new TarFormat()); //$NON-NLS-1$
		register("tgz", new TgzFormat()); //$NON-NLS-1$
		register("tbz2", new Tbz2Format()); //$NON-NLS-1$
		register("txz", new TxzFormat()); //$NON-NLS-1$
		register("zip", new ZipFormat()); //$NON-NLS-1$
	}

	/**
	 * Clean up by deregistering all formats that were registered
	 * by registerAll().
	 *
	 * Not thread-safe.
	 */
	public static void unregisterAll() {
		for (String name : myFormats) {
			ArchiveCommand.unregisterFormat(name);
		}
		myFormats.clear();
	}
}

==> jgit_4.11.9.orig.tar.xz: jgit-4.11.9.201909030838-r/org.eclipse.jgit.archive/src/org/eclipse/jgit/archive/ArchiveFormats.java <==
/*
 * Copyright (C) 2013 Google Inc.
 * and other copyright owners as documented in the project's IP log.
 *
 * This program and the accompanying materials are made available
 * under the terms of the Eclipse Distribution License v1.0 which
 * accompanies this distribution, is reproduced below, and is
 * available at http://www.eclipse.org/org/documents/edl-v10.php
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided
 *   with the distribution.
 *
 * - Neither the name of the Eclipse Foundation, Inc. nor the
 *   names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior
 *   written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.eclipse.jgit.archive;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.jgit.api.ArchiveCommand;

/**
 * Registers all format types from the org.eclipse.jgit.archive package for use
 * via the ArchiveCommand API.
 *
 * See {@link org.eclipse.jgit.archive.FormatActivator} for an OSGi bundle
 * activator that performs the same registration automatically.
 */
public class ArchiveFormats {
	private static final List<String> myFormats = new ArrayList<>();

	private static final void register(String name, ArchiveCommand.Format<?> fmt) {
		myFormats.add(name);
		ArchiveCommand.registerFormat(name, fmt);
	}

	/**
	 * Register all included archive formats so they can be used
	 * as arguments to the ArchiveCommand.setFormat() method.
	 *
	 * Not thread-safe.
	 */
	public static void registerAll() {
		register("tar", new TarFormat()); //$NON-NLS-1$
		register("tgz", new TgzFormat()); //$NON-NLS-1$
		register("tbz2", new Tbz2Format()); //$NON-NLS-1$
		register("txz", new TxzFormat()); //$NON-NLS-1$
		register("zip", new ZipFormat()); //$NON-NLS-1$
	}

	/**
	 * Clean up by deregistering all formats that were registered
	 * by registerAll().
	 *
	 * Not thread-safe.
	 */
	public static void unregisterAll() {
		for (String name : myFormats) {
			ArchiveCommand.unregisterFormat(name);
		}
		myFormats.clear();
	}
}
